@@ -3,7 +3,8 @@
 filter_throughput_time_threshold <- function(eventlog,
 									  lower_threshold = NULL,
 									  upper_threshold = NULL,
-									  reverse = F)
+									  reverse = F,
+									  units)
 {
 
 
@@ -13,11 +14,11 @@ filter_throughput_time_threshold <- function(eventlog,
 		upper_threshold <- Inf
 
 
-	case_durations <- durations(eventlog = eventlog)
+	case_durations <- throughput_time(eventlog = eventlog, "case", units = units)
 	colnames(case_durations)[colnames(case_durations)==case_id(eventlog)] <- "case_classifier"
 	colnames(eventlog)[colnames(eventlog)==case_id(eventlog)] <- "case_classifier"
 
-	case_selection <- filter(case_durations, duration_in_days >= lower_threshold, duration_in_days <= upper_threshold)$case_classifier
+	case_selection <- filter(case_durations, throughput_time >= lower_threshold, throughput_time <= upper_threshold)$case_classifier
 	if(reverse == FALSE)
 		f_eventlog <- filter(eventlog, case_classifier %in% case_selection)
 	else
