@@ -11,10 +11,10 @@ trace_length_log <- function(eventlog) {
 	s <- c(s, St.Dev = sd(csum$trace_length))
 	s <- c(s, IQR = s[5] - s[2])
 	names(s) <- c("min","q1","median","mean","q3","max","st_dev","iqr")
-	s <- data.frame(s)
-	s <- as.data.frame(t(s))
+	s <- as.data.frame(s)
+	s <- t(s)
 	row.names(s) <- NULL
-	s <- tbl_df(s)
+
 	return(s)
 
 }
